'use strict';

var core = require('@shikijs/core');
var engineJavascript = require('@shikijs/engine-javascript');
var React = require('react');

var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};
function _log(...args) {
  console.log("[ShikiProvider]", ...args);
}
const ShikiContext = React.createContext(null);
function ShikiProvider({ children, initialLanguages, initialThemes }) {
  const [highlighter, setHighlighter] = React.useState(null);
  const [isReady, setIsReady] = React.useState(false);
  const [error, setError] = React.useState(null);
  React.useEffect(() => {
    const initHighlighter = () => __async(this, null, function* () {
      var _a;
      try {
        const highlighterInstance = yield core.createHighlighterCore({
          engine: engineJavascript.createJavaScriptRegexEngine()
        });
        const activeTheme = initialThemes[0];
        const testCode = `
          // This is a comment
          function test() {
            const str = "hello";
            return str;
          }
        `;
        const testTokens = highlighterInstance.codeToTokens(testCode.trim(), {
          lang: "typescript",
          theme: activeTheme,
          includeExplanation: true
        });
        _log("Test tokenization:", {
          tokens: (_a = testTokens.tokens[0]) == null ? void 0 : _a.map((token) => {
            var _a2, _b, _c, _d;
            return {
              content: token.content,
              color: token.color,
              scopes: (_b = (_a2 = token.explanation) == null ? void 0 : _a2[0]) == null ? void 0 : _b.scopes.map((s) => s.scopeName),
              matches: (_d = (_c = token.explanation) == null ? void 0 : _c[0]) == null ? void 0 : _d.scopes.flatMap((s) => s.themeMatches || []).map((m) => ({
                scope: m.scope,
                color: m.settings.foreground
              }))
            };
          }),
          theme: highlighterInstance.getTheme(activeTheme)
        });
        setHighlighter(highlighterInstance);
        setIsReady(true);
        setError(null);
      } catch (err) {
        console.error("Highlighter initialization failed:", err);
        setError(err instanceof Error ? err : new Error("Initialization failed"));
        setIsReady(false);
      }
    });
    initHighlighter();
  }, [initialLanguages, initialThemes]);
  const value = React.useMemo(
    () => ({
      highlighter,
      isReady,
      error
    }),
    [highlighter, isReady, error]
  );
  return /* @__PURE__ */ React.createElement(ShikiContext.Provider, { value }, children);
}
function useShiki() {
  const context = React.useContext(ShikiContext);
  if (!context) {
    throw new Error("useShiki must be used within a ShikiProvider");
  }
  return context;
}

exports.ShikiProvider = ShikiProvider;
exports.useShiki = useShiki;
//# sourceMappingURL=SyntaxContext.js.map
